@@ -2,8 +2,8 @@ __version__ = "0.1.0"
 __author__ = 'Vlad Romanenko'
 
 
-
 from abc import ABC, abstractmethod
+from Logger import logger
 
 
 class MaterialCreator(ABC):
@@ -16,6 +16,8 @@ class MaterialCreator(ABC):
     def create_material(
             self,
             name: str,
+            nuclides: list,
+            concentrations: list,
             **kwargs
     ):
         pass
@@ -30,6 +32,8 @@ class NumberedMaterialsCreator(ABC):
     def create_materials(
             self,
             name: str,
+            nuclides: list,
+            concentrations: list,
             **kwargs
     ):
         pass
@@ -45,6 +49,8 @@ class CoreMaterialsCreator(ABC):
     def create_materials(
             self,
             name: str,
+            nuclides: list,
+            concentrations: list,
             **kwargs
     ):
         pass
